#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Part of reusable package
#
# Copyright (c) 2020 - Ohidur Rahman Bappy - MIT License
"""String Related Functions.

Contains a handful of string related functions.
"""

from .datetime_functions import generate_all_datetime_regex
from .iterable_functions import groupby_count
from .network_functions import *
from .string_functions import *
from .utility_functions import *
from .fake_useragent import random_useragent
